<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>AddProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="28"/>
        <source>Please enter a profile name.</source>
        <translation>Bitte einen Profilnamen eingeben.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="29"/>
        <source>A profile with this name already exists.</source>
        <translation>Ein gleichnamiges Profil existiert bereits.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="25"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="26"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>AddRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="94"/>
        <source>Repository Path:</source>
        <translation>Repository-Pfad:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="97"/>
        <source>Choose Location of Borg Repository</source>
        <translation>Wähle den Speicherort des Borg-Repositories</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="126"/>
        <source>Repository URL:</source>
        <translation>Repository-URL:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="152"/>
        <source>Unable to add your repository.</source>
        <translation>Kann dieses Repository nicht hinzufügen.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="179"/>
        <source>Please enter a valid repo URL or select a local path.</source>
        <translation>Bitte eine gültige Repo-URL eingeben oder einen lokalen Pfad auswählen.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="183"/>
        <source>This repo has already been added.</source>
        <translation>Dieses Repository wurde bereits hinzugefügt.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="119"/>
        <source>Show my passwords</source>
        <translation>Meine Passwörter anzeigen</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="104"/>
        <source>Autofilled password from password manager.</source>
        <translation>Aus der Kennwortverwaltung eingefügtes Kennwort</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="116"/>
        <source>Hide my passwords</source>
        <translation>Meine Passwörter verstecken</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="63"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="156"/>
        <source>Repokey-Blake2 (Recommended, key stored in repository)</source>
        <translation>Repokey-Blake2 (empfohlen, Schlüssel wird im Repository gespeichert)</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="157"/>
        <source>Repokey</source>
        <translation>Repokey</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="158"/>
        <source>Keyfile-Blake2 (Key stored in home directory)</source>
        <translation>Keyfile-Blake2 (Schlüssel wird im Home-Verzeichnis gespeichert)</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="159"/>
        <source>Keyfile</source>
        <translation>Keyfile</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="160"/>
        <source>None (not recommended)</source>
        <translation>Unverschlüsselt (nicht empfohlen)</translation>
    </message>
</context>
<context>
    <name>AddRepository</name>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="96"/>
        <source>Initialize New Backup Repository</source>
        <translation>Initialisiere Neues Backup-Repository</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="103"/>
        <source>Repository URL:</source>
        <translation>Repository-URL:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="118"/>
        <source>csvis8xq@csvis8xq.repo.borgbase.com:repo</source>
        <translation>csvis8xq@csvis8xq.repo.borgbase.com:repo</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="142"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="240"/>
        <source>Encryption:</source>
        <translation>Verschlüsselung:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="218"/>
        <source>SSH Key:</source>
        <translation>SSH-Schlüssel:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="232"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>SSH-Schlüssel automatisch auswählen (Standardeinstellung)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="69"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="197"/>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="257"/>
        <source>Extra Borg Arguments:</source>
        <translation>Extra Optionen für Borg Kommando:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="155"/>
        <source>Borg passphrase:</source>
        <translation>Kennwort für Borgrepository:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="182"/>
        <source>Confirm passphrase:</source>
        <translation>Passwort bestätigen:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="189"/>
        <source>TextLabel</source>
        <translation>Textfeld</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="125"/>
        <source>Choose a local folder</source>
        <translation>Ein lokales Verzeichnis auswählen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="139"/>
        <source>Choose a remote repository</source>
        <translation>Ein entferntes Repository auswählen</translation>
    </message>
</context>
<context>
    <name>ArchiveTab</name>
    <message>
        <location filename="../../views/archive_tab.py" line="228"/>
        <source>Archives for %s</source>
        <translation>Archive für %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="263"/>
        <source>Archives</source>
        <translation>Archive</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="365"/>
        <source>Preview: %s</source>
        <translation>Vorschau: %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="369"/>
        <source>Error in archive name template.</source>
        <translation>Fehler in der Archiv-Namens-Vorlage.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="427"/>
        <source>Pruning finished.</source>
        <translation>Ausdünnen beendet.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="446"/>
        <source>Refreshed archives.</source>
        <translation>Archive aufgefrischt.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="578"/>
        <source>Choose Mount Point</source>
        <translation>Einhängepunkt auswählen</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="583"/>
        <source>Mounted successfully.</source>
        <translation>Erfolgreich eingehängt.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="644"/>
        <source>Mount point not active.</source>
        <translation>Einhängepunkt bereits ausgehängt.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="653"/>
        <source>Un-mounted successfully.</source>
        <translation>Erfolgreich ausgehängt.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="703"/>
        <source>Select an archive to restore first.</source>
        <translation>Zuerst ein Archiv zum Wiederherstellen auswählen.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="723"/>
        <source>Choose Extraction Point</source>
        <translation>Extrahierungs-Punkt auswählen</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="788"/>
        <source>Archive deleted.</source>
        <translation>Archiv gelöscht.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="773"/>
        <source>Confirm deletion</source>
        <translation>Löschen bestätigen</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="888"/>
        <source>No archive selected</source>
        <translation>Kein Archiv ausgewählt</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="773"/>
        <source>Are you sure you want to delete the archive?</source>
        <translation>Soll das gewählte Archiv gelöscht werden?</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="759"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="760"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="193"/>
        <source>Action cancelled.</source>
        <translation>Vorgang abgebrochen.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="670"/>
        <source>Unmounting failed. Make sure no programs are using {}</source>
        <translation>Aushängen fehlgeschlagen. Stelle sicher, dass keine Programme {} benutzen.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="862"/>
        <source>Change name</source>
        <translation>Name ändern</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="862"/>
        <source>New archive name:</source>
        <translation>Neuer Name für Archiv:</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="872"/>
        <source>Archive name cannot be blank.</source>
        <translation>Archivname darf nicht leer sein.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="877"/>
        <source>An archive with this name already exists.</source>
        <translation>Ein Archiv mit diesem Namen existiert bereits.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="892"/>
        <source>Archive renamed.</source>
        <translation>Archiv umbenannt.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="463"/>
        <source>Refreshed archive.</source>
        <translation>Archive aufgefrischt.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="152"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="338"/>
        <source>(Select exactly one archive)</source>
        <translation>(Wähle genau ein Archiv aus)</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="531"/>
        <source>Unmount</source>
        <translation>Aushängen</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="536"/>
        <source>Mount…</source>
        <translation>Einhängen…</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="316"/>
        <source>(Select two archives)</source>
        <translation>(Wähle zwei Archive aus)</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="514"/>
        <source>Unmount the selected archive from the file system.</source>
        <translation>Hängt das gewählte Archiv aus dem Dateisystem aus.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="519"/>
        <source>Mount the selected archive as a folder in the file system.</source>
        <translation>Bindet das gewählte Archiv in das Dateisystem ein.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="532"/>
        <source>Unmount the repository from the file system.</source>
        <translation>Hängt das Repository aus dem Dateisystem aus.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="538"/>
        <source>Mount the repository as a folder in the file system.</source>
        <translation>Bindet das Repository als Verzeichnis ins Dateisystem ein.</translation>
    </message>
</context>
<context>
    <name>BorgBreakJob</name>
    <message>
        <location filename="../../borg/break_lock.py" line="12"/>
        <source>Repository lock broken. Please redo your last action.</source>
        <translation>Sperre des Repositorys wurde aufgehoben. Bitte letzte Aktion wiederholen.</translation>
    </message>
    <message>
        <location filename="../../borg/break_lock.py" line="8"/>
        <source>Breaking repository lock…</source>
        <translation>Hebe Repositorysperre auf...</translation>
    </message>
</context>
<context>
    <name>BorgCheckJob</name>
    <message>
        <location filename="../../borg/check.py" line="27"/>
        <source>Check completed.</source>
        <translation>Überprüfung abgeschlossen.</translation>
    </message>
    <message>
        <location filename="../../borg/check.py" line="24"/>
        <source>Repo check failed. See logs for details.</source>
        <translation>Überprüfung des Repositorys fehlgeschlagen. Details dazu im Log.</translation>
    </message>
    <message>
        <location filename="../../borg/check.py" line="10"/>
        <source>Starting consistency check…</source>
        <translation>Starte Konsistenzprüfung…</translation>
    </message>
</context>
<context>
    <name>BorgCompactJob</name>
    <message>
        <location filename="../../borg/compact.py" line="11"/>
        <source>Starting repository compaction...</source>
        <translation>Beginne mit dem Defragmentieren des Repositorys.</translation>
    </message>
    <message>
        <location filename="../../borg/compact.py" line="25"/>
        <source>Errors during compaction. See logs for details.</source>
        <translation>Defragmentierung fehlgeschlagen. Details finden sich in den Logs.</translation>
    </message>
    <message>
        <location filename="../../borg/compact.py" line="27"/>
        <source>Compaction completed.</source>
        <translation>Defragmentierung abgeschlossen.</translation>
    </message>
</context>
<context>
    <name>BorgCreateJob</name>
    <message>
        <location filename="../../borg/create.py" line="36"/>
        <source>Backup finished with warnings. See logs for details.</source>
        <translation>Datensicherung mit Warnungen abgeschlossen. Siehe Logdateien für Details.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="38"/>
        <source>Backup finished.</source>
        <translation>Datensicherung abgeschlossen.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="45"/>
        <source>Backup started.</source>
        <translation>Datensicherung gestartet.</translation>
    </message>
</context>
<context>
    <name>BorgDeleteJob</name>
    <message>
        <location filename="../../borg/delete.py" line="23"/>
        <source>Archive deleted.</source>
        <translation>Archiv gelöscht.</translation>
    </message>
    <message>
        <location filename="../../borg/delete.py" line="10"/>
        <source>Deleting archive…</source>
        <translation>Lösche Archiv…</translation>
    </message>
</context>
<context>
    <name>BorgDiffJob</name>
    <message>
        <location filename="../../borg/diff.py" line="13"/>
        <source>Obtained differences between archives.</source>
        <translation>Unterschiede zwischen den Archiven erhalten.</translation>
    </message>
    <message>
        <location filename="../../borg/diff.py" line="9"/>
        <source>Requesting differences between archives…</source>
        <translation>Fordere die Archivunterschiede an…</translation>
    </message>
</context>
<context>
    <name>BorgExtractJob</name>
    <message>
        <location filename="../../borg/extract.py" line="13"/>
        <source>Restored files from archive.</source>
        <translation>Dateien aus Archiv wiederhergestellt.</translation>
    </message>
    <message>
        <location filename="../../borg/extract.py" line="8"/>
        <source>Downloading files from archive…</source>
        <translation>Lade Dateien aus dem Archiv herunter…</translation>
    </message>
</context>
<context>
    <name>BorgInfoArchiveJob</name>
    <message>
        <location filename="../../borg/info_archive.py" line="14"/>
        <source>Refreshing archive done.</source>
        <translation>Auffrischen des Archivs erledigt.</translation>
    </message>
    <message>
        <location filename="../../borg/info_archive.py" line="9"/>
        <source>Refreshing archive…</source>
        <translation>Aktualisiere Archivmetadaten…</translation>
    </message>
</context>
<context>
    <name>BorgInfoRepoJob</name>
    <message>
        <location filename="../../borg/info_repo.py" line="9"/>
        <source>Validating existing repo…</source>
        <translation>Validiere bestehendes Repository…</translation>
    </message>
</context>
<context>
    <name>BorgInitJob</name>
    <message>
        <location filename="../../borg/init.py" line="8"/>
        <source>Setting up new repo…</source>
        <translation>Erstelle neues Repository…</translation>
    </message>
</context>
<context>
    <name>BorgJob</name>
    <message>
        <location filename="../../borg/borg_job.py" line="66"/>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="67"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="68"/>
        <source>Deduplicated</source>
        <translation>Dedupliziert</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="69"/>
        <source>Compressed</source>
        <translation>Komprimiert</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="306"/>
        <source>Task started</source>
        <translation>Aufgabe gestartet</translation>
    </message>
</context>
<context>
    <name>BorgListArchiveJob</name>
    <message>
        <location filename="../../borg/list_archive.py" line="12"/>
        <source>Done getting archive content.</source>
        <translation>Archiv-Inhalt abrufen erledigt.</translation>
    </message>
    <message>
        <location filename="../../borg/list_archive.py" line="8"/>
        <source>Getting archive content…</source>
        <translation>Rufe Inhalt des Archivs ab…</translation>
    </message>
</context>
<context>
    <name>BorgListRepoJob</name>
    <message>
        <location filename="../../borg/list_repo.py" line="15"/>
        <source>Refreshing archives done.</source>
        <translation>Auffrischen der Archive erledigt.</translation>
    </message>
    <message>
        <location filename="../../borg/list_repo.py" line="10"/>
        <source>Refreshing archives…</source>
        <translation>Aktualisiere Archivliste…</translation>
    </message>
</context>
<context>
    <name>BorgMountJob</name>
    <message>
        <location filename="../../borg/mount.py" line="9"/>
        <source>Mounting archive into folder…</source>
        <translation>Hänge Archiv in Ordner ein…</translation>
    </message>
</context>
<context>
    <name>BorgPruneJob</name>
    <message>
        <location filename="../../borg/prune.py" line="24"/>
        <source>Pruning done.</source>
        <translation>Ausdünnen erledigt.</translation>
    </message>
    <message>
        <location filename="../../borg/prune.py" line="11"/>
        <source>Pruning old archives…</source>
        <translation>Dünne alte Archive aus…</translation>
    </message>
</context>
<context>
    <name>BorgUmountJob</name>
    <message>
        <location filename="../../borg/umount.py" line="10"/>
        <source>Unmounting archive…</source>
        <translation>Hänge Archiv aus…</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="25"/>
        <source>Archive:</source>
        <translation>Archiv:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 from November 16, 2018</source>
        <translation>nyx2.local-2018-11-16T09:49:58 from November 16, 2018</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="63"/>
        <source>Note: If you select a top-level folder and deselect its children, they will still be restored.</source>
        <translation>Bitte beachten: Wenn Sie einen Ordner auf oberster Ebene selektieren und alle Elemente darunter deselektieren, werden sie trotzdem wieder hergestellt.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="106"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="35"/>
        <source>Add Backup Profile</source>
        <translation>Backup-Profil hinzufügen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="42"/>
        <source>Generate SSH Key</source>
        <translation>SSH-Schlüssel erzeugen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="54"/>
        <source>Key Format:</source>
        <translation>Schlüssel-Format:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="71"/>
        <source>Key Length:</source>
        <translation>Schlüssel-Länge:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="93"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 or 4096 for RSA, 384 or 521 for ECDSA. Fixed for Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;More&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 oder 4096 für RSA, 384 oder 521 für ECDSA. Fest für Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Mehr&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="106"/>
        <source>Output File:</source>
        <translation>Ausgabe-Datei:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="25"/>
        <source>Select two archives</source>
        <translation>Wähle zwei Archive aus</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="60"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="65"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="70"/>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="75"/>
        <source>Mount Point</source>
        <translation>Einhängepunkt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="80"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="113"/>
        <source>Diff</source>
        <translation>Unterschiede</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="25"/>
        <source>Difference between</source>
        <translation>Unterschiede zwischen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 </source>
        <translation>nyx2.local-2018-11-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="45"/>
        <source>and</source>
        <translation>und</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="58"/>
        <source>nyx2.local-2018-10-16T09:49:58 </source>
        <translation>nyx2.local-2018-10-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="101"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="26"/>
        <source>Include borg passphrase in export</source>
        <translation>Borg-Passwort mitexportieren</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="25"/>
        <source>Borg passphrase:</source>
        <translation>Borg-Passwort:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="56"/>
        <source>Overwrite existing profile</source>
        <translation>Bestehendes Profil überschreiben</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="63"/>
        <source>Overwrite existing settings</source>
        <translation>Bestehende Einstellungen überschreiben</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="23"/>
        <source>Include Borg passphrase in export. Use with caution!</source>
        <translation>Borgpasswort dem Export beifügen. Vorsicht wegen Datendiebstahls!</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="32"/>
        <source>Enter passphrase</source>
        <translation>Kennwort eingeben</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="12"/>
        <source>Add Profile</source>
        <translation>Profil hinzufügen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;
&lt;p&gt;Profiles allow configuring of different backup and repository settings including different schedules.&lt;/p&gt;
&lt;p&gt;All profiles will be able to access the same repositories as well as the same &lt;span style=&quot; font-style:italic;&quot;&gt;ssh&lt;/span&gt; keys. The global application settings in &lt;span style=&quot; font-style:italic;&quot;&gt;Misc&lt;/span&gt; are shared across profiles.&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Mit Profilen können verschiedene Zeitpläne, Repositorys und Sicherungsoptionen konfiguriert werden.&lt;/p&gt;
&lt;p&gt;Alle Profile können dieselben Repositorys und dieselben &lt;span style=&quot; font-style:italic;&quot;&gt;SSH&lt;/span&gt;-Schlüssel verwenden. Der Reiter &lt;span style=&quot; font-style:italic;&quot;&gt;Allgemein&lt;/span&gt; legt Profil übergreifend die globalen Programmeinstellungen fest.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="87"/>
        <source>Profile Name:</source>
        <translation>Profilname:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="121"/>
        <source>Do not change this if you want SSH to automatically find the key.</source>
        <translation>Behalten Sie dies bei, wenn SSH den Schlüssel automatisch finden soll.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="14"/>
        <source>Choose archives for diff</source>
        <translation>Zu vergleichende Archive auswählen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="14"/>
        <source>Diff Result</source>
        <translation>Unterschiede</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="14"/>
        <source>Choose files to extract</source>
        <translation>Zu extrahierende Dateien auswählen</translation>
    </message>
</context>
<context>
    <name>EditProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="69"/>
        <source>Rename Profile</source>
        <translation>Profilname ändern</translation>
    </message>
</context>
<context>
    <name>ExistingRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="206"/>
        <source>Connect to existing Repository</source>
        <translation>Mit existierendem Repository verbinden</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="224"/>
        <source>Show my password</source>
        <translation>Mein Passwort anzeigen</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="221"/>
        <source>Hide my password</source>
        <translation>Mein Passwort verstecken</translation>
    </message>
</context>
<context>
    <name>ExportWindow</name>
    <message>
        <location filename="../../views/export_window.py" line="30"/>
        <source>Export Profile</source>
        <translation>Profil exportieren</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="44"/>
        <source>Save profile_export</source>
        <translation>profile_export speichern</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="56"/>
        <source>Error while exporting</source>
        <translation>Fehler beim Exportieren</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="72"/>
        <source>The file {} could not be created. Please choose another location.</source>
        <translation>Die Datei {} konnte nicht erstellt werden. Bitte ein anderes Verzeichnis auswählen.</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="79"/>
        <source>Profile export successful!</source>
        <translation>Profil erfolgreich exportiert!</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="79"/>
        <source>Profile export written to {}.</source>
        <translation>Profil nach {} exportiert.</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="39"/>
        <source>Disclose your borg passphrase (No passphrase set)</source>
        <translation>Borgpasswort anhängen (Kein Kennwort festgelegt)</translation>
    </message>
</context>
<context>
    <name>ExtractDialog</name>
    <message>
        <location filename="../../views/extract_dialog.py" line="76"/>
        <source>Extract</source>
        <translation>Entpacken</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="41"/>
        <source>Archives</source>
        <translation>Archive</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="147"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="96"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="157"/>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="162"/>
        <source>Mount Point</source>
        <translation>Einhängepunkt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="167"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="77"/>
        <source>Check</source>
        <translation>Prüfen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="90"/>
        <source>Prune</source>
        <translation>Ausdünnen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="207"/>
        <source>Refresh</source>
        <translation>Auffrischen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="357"/>
        <source>Prune Options and Archive Naming</source>
        <translation>Ausdünnungs-Optionen und Archiv-Namensgebung</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="569"/>
        <source>No matter what, keep all archives of the last:</source>
        <translation>Außerdem, behalte alle Archive der letzten:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="582"/>
        <source>24H, 1d, 52w, 12m, 1y</source>
        <translation>24H, 1d, 52w, 12m, 1y</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="648"/>
        <source>Archive Name:</source>
        <translation>Archiv-Name:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="638"/>
        <source>Available variables: hostname, profile_id, profile_slug, now, utc_now, user</source>
        <translation>Verfügbare Variablen: hostname, profile_id, profile_slug, now, utc_now, user</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="616"/>
        <source>{hostname}-{profile_slug}-</source>
        <translation>{hostname}-{profile_slug}-</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="606"/>
        <source>Prune Prefix:</source>
        <translation>Ausdünnungs-Präfix:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="77"/>
        <source>0.0</source>
        <translation>0.0</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="65"/>
        <source>Repository:</source>
        <translation>Repository:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="131"/>
        <source>Select Backup Destination</source>
        <translation>Wähle Datensicherungs-Ziel</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="206"/>
        <source>SSH Key:</source>
        <translation>SSH-Schlüssel:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="268"/>
        <source>Compression:</source>
        <translation>Kompression:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="368"/>
        <source>Encryption:</source>
        <translation>Verschlüsselung:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="398"/>
        <source>Original Size:</source>
        <translation>Ursprüngliche Größe:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="412"/>
        <source>Deduplicated Size:</source>
        <translation>Deduplizierte Größe:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="426"/>
        <source>Compressed Size:</source>
        <translation>Komprimierte Größe:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="51"/>
        <source>Schedule</source>
        <translation>Planung</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="437"/>
        <source>weeks</source>
        <translation>Wochen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="489"/>
        <source>Next Backup:</source>
        <translation>Nächstes Backup:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="527"/>
        <source>Networks</source>
        <translation>Netzwerke</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="544"/>
        <source>Allowed Networks:</source>
        <translation>Erlaubte Netzwerke:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="582"/>
        <source>Log</source>
        <translation>Protokoll</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="604"/>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="609"/>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="614"/>
        <source>Subcommand</source>
        <translation>Unter-Kommando</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="619"/>
        <source>Repository</source>
        <translation>Repository</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="624"/>
        <source>Returncode</source>
        <translation>Returncode</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="641"/>
        <source>Shell Commands</source>
        <translation>Shell-Kommandos</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="56"/>
        <source>Source Folders and Files to Back Up:</source>
        <translation>Zu sichernde Quell-Ordner und -Dateien:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="168"/>
        <source>Exclude If Present (exclude folders with these files):</source>
        <translation>Ausschließen, Wenn Vorhanden (schließe Ordner mit diesen Dateien aus):</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="338"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To mount archives, first install &amp;quot;FUSE for macOS&amp;quot; from &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;here&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Um Archive einzuhängen, installiere &amp;quot;FUSE für macOS&amp;quot; von &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;hier&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="372"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pruning removes older archives. You can choose the number of hourly, daily, etc. archives to preserve. Usually you will keep more newer and fewer old archives. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ausdünnen entfernt ältere Archive. Sie können die Anzahl der stündlichen, täglichen, etc. Archive wählen, die Sie behalten möchten. Üblicherweise werden Sie mehr neue und weniger alte Archive behalten. &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Mehr&lt;/span&gt;&lt;/a&gt; lesen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="70"/>
        <source>Vorta Version:</source>
        <translation>Vorta Version:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="87"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Report&lt;/span&gt;&lt;/a&gt; a Bug |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;(&lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Melden&lt;/span&gt;&lt;/a&gt; eines Fehlers)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Log&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Log&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="133"/>
        <source>Borg Version:</source>
        <translation>Borg Version:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="140"/>
        <source>1.1.8</source>
        <translation>1.1.8</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="147"/>
        <source>/usr/bin/borg</source>
        <translation>/usr/bin/borg</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="158"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Exclude Patterns (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ausschluss-Muster (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;mehr&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="203"/>
        <source>E.g. .nobackup</source>
        <translation>Zum Beispiel .nobackup</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="641"/>
        <source>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</source>
        <translation>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="91"/>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="101"/>
        <source>File Count</source>
        <translation>Anzahl Dateien</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="54"/>
        <source>Refresh archive list</source>
        <translation>Archivliste aktualisieren</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="74"/>
        <source>Check the consistancy of the repository</source>
        <translation>Konsistenz des Repositorys überprüfen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="87"/>
        <source>Prune the archives in this repository</source>
        <translation>Archive des Repositorys ausdünnen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="100"/>
        <source>Compact</source>
        <translation>Optimieren</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="204"/>
        <source>Refresh selected archive</source>
        <translation>Metadaten des ausgewählten Archivs aktualisieren</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="239"/>
        <source>Extract selected archive</source>
        <translation>Ausgewähltes Archiv entpacken</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="242"/>
        <source>Extract…</source>
        <translation>Entpacken…</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="258"/>
        <source>Rename selected archive</source>
        <translation>Ausgewähltes Archiv umbenennen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="261"/>
        <source>Rename…</source>
        <translation>Umbenennen…</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="277"/>
        <source>Delete selected archive</source>
        <translation>Ausgewähltes Archiv endgültig entfernen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="280"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="312"/>
        <source>Compare two archives</source>
        <translation>Zwei Archive vergleichen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="406"/>
        <source>Hourly:</source>
        <translation>Stündlich:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="542"/>
        <source>Use -1 for unlimited</source>
        <translation>Keine Begrenzung bei einem Wert von -1</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="439"/>
        <source>Daily:</source>
        <translation>Täglich:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="472"/>
        <source>Weekly:</source>
        <translation>Wöchentlich:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="532"/>
        <source>Annual:</source>
        <translation>Jährlich:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="95"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For simple and secure backup hosting, try &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Probieren Sie &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt; für einfaches und sicheres Hosting von Datensicherungen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="247"/>
        <source>Copy to clipboard</source>
        <translation>In die Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="139"/>
        <source>Unlink repository without deleting it.</source>
        <translation>Repository abkoppeln, ohne es zu löschen.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="311"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Help on compression types&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Mehr Informationen über Komprimierungsverfahren&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="76"/>
        <source>Backup schedule:</source>
        <translation>Sicherungszeitplan:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="83"/>
        <source>Manual only</source>
        <translation>Ausschließlich manuell</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="98"/>
        <source>Backup periodically</source>
        <translation>Periodische Datensicherung</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="401"/>
        <source>Interval:</source>
        <translation>Intervall:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="191"/>
        <source>Backup daily</source>
        <translation>Tägliche Datensicherung</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="238"/>
        <source>Time:</source>
        <translation>Uhrzeit:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="285"/>
        <source>Missed backups:</source>
        <translation>Verpasste Sicherungstermine:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="298"/>
        <source>Run missed backups on startup or wakeup</source>
        <translation>Verpasste Datensicherungen beim Starten oder Aufwachen nachholen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="325"/>
        <source>Autopruning:</source>
        <translation>Automatisches Ausdünnen:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="332"/>
        <source>Prune after each backup</source>
        <translation>Alte Archive nach jeder Sicherung ausdünnen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="339"/>
        <source>Validation:</source>
        <translation>Validierung:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="354"/>
        <source>Validate repository data</source>
        <translation>Repositorydaten überprüfen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="496"/>
        <source>None scheduled</source>
        <translation>Nicht angesetzt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="563"/>
        <source>Run backups over metered networks</source>
        <translation>Datensicherung über kostenpflichtige Netzwerke durchführen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="659"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Run custom shell commands before and after each backup. The actual backup and post-backup command will only run, if the pre-backup command exits without error (return code 0). Available variables: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Eigene Shell-Befehle vor und nach jeder Sicherung ausführen. Die eigentliche Datensicherung sowie das Aufrufen des Postsicherungskommandos geschieht nur, wenn das Präsicherungskommando ohne Fehler beendet wurde (return code 0). Verfügbare Platzhalter: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="683"/>
        <source>Pre-backup:</source>
        <translation>Vor der Sicherung:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="711"/>
        <source>echo &quot;Before backup of $repo_url&quot;</source>
        <translation>echo &quot;Vor der Sicherung nach $repo_url&quot;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="731"/>
        <source>Post-backup:</source>
        <translation>Nach der Sicherung:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="750"/>
        <source>echo &quot;Backup of $repo_url ended with $returncode.&quot;</source>
        <translation>echo &quot;Sicherung nach $repo_url mit $returncode beendet.&quot;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="771"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Extra arguments for &lt;span style=&quot; font-style:italic;&quot;&gt;borg create&lt;/span&gt;. Possible options are listed in the &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;the borg documentation&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Zusätzliche Argumente für &lt;span style=&quot; font-style:italic;&quot;&gt;borg create&lt;/span&gt;. Mögliche Parameter werden in der &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Borg-Dokumentation&lt;/span&gt;&lt;/a&gt;erklärt.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="793"/>
        <source>--dry-run --noflags</source>
        <translation>--dry-run --noflags</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="111"/>
        <source>Recalculate source size and file count</source>
        <translation>Ausgangsgröße und Dateianzahl erneut berechnen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="131"/>
        <source>Add sources</source>
        <translation>Datenquellen hinzufügen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="141"/>
        <source>Remove the selected source</source>
        <translation>Ausgewählte Datenquelle entfernen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="315"/>
        <source>Diff</source>
        <translation>Unterschiede</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="502"/>
        <source>Monthly:</source>
        <translation>Monatlich:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="187"/>
        <source>E.g. */.cache</source>
        <translation>z.B. */.cache</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="576"/>
        <source>“&amp;lt;int&amp;gt;&amp;lt;char&amp;gt;”, where char is “H”, “d”, “w”, “m”, “y”</source>
        <translation>“&amp;lt;Zahl&amp;gt;&amp;lt;Zeichen&amp;gt;”, wobei Zeichen eines der folgenden Einheiten sein muss: “H”, “d”, “w”, “m”, “y”</translation>
    </message>
</context>
<context>
    <name>ImportWindow</name>
    <message>
        <location filename="../../views/import_window.py" line="25"/>
        <source>Import Profile</source>
        <translation>Profil importieren</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="59"/>
        <source>Error while importing</source>
        <translation>Fehler beim Importieren</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="75"/>
        <source>Schema upgrade failure, file a bug report with the link in the Misc tab with the following error: 
 {0} 
 {1}</source>
        <translation>Schema-Upgrade Fehler, erstelle einen Bugreport auf dem Link um &quot;Misc&quot;-Tab, mit folgendem Fehler: 
 {0} 
 {1}</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="78"/>
        <source>Newer profile_export export files cannot be used on older versions.</source>
        <translation>Neuere profile_export Export-Dateien können nicht von älteren Versionen verwendet werden.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="80"/>
        <source>Cannot read profile_export export file due to permission error.</source>
        <translation>Die profile_export exportierte Datei kann aufgrund der Dateiberechtigungen nicht gelesen werden.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="82"/>
        <source>Profile export file not found.</source>
        <translation>Profil-Export Datei nicht gefunden.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="33"/>
        <source>Enter passphrase (already loaded from the export file)</source>
        <translation>Kennwort eingeben (bereits aus der Exportdatei importiert)</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="40"/>
        <source>Enter passphrase (already loaded from your keyring)</source>
        <translation>Kennwort eingeben (bereits aus dem Schlüsselbund geladen)</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="50"/>
        <source>(Name is not used yet)</source>
        <translation>(Namen noch nicht belegt)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../views/main_window.py" line="264"/>
        <source>Task cancelled</source>
        <translation>Aufgabe abgebrochen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="51"/>
        <source>Current Profile:</source>
        <translation>Aktuelles Profil:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="154"/>
        <source>Repository</source>
        <translation>Repository</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="159"/>
        <source>Sources</source>
        <translation>Quellen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="164"/>
        <source>Schedule</source>
        <translation>Zeitplan</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="169"/>
        <source>Archives</source>
        <translation>Archive</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="174"/>
        <source>Misc</source>
        <translation>Diverses</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="196"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="40"/>
        <source>Start Backup</source>
        <translation>Datensicherung starten</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="235"/>
        <source>Latest</source>
        <translation>Neuestes</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="240"/>
        <source>Reset App</source>
        <translation>App zurücksetzen</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="172"/>
        <source>Are you sure you want to delete profile &apos;{}&apos;?</source>
        <translation>Soll das gewählte Archiv gelöscht werden?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="173"/>
        <source>Confirm deletion</source>
        <translation>Löschen bestätigen</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="281"/>
        <source>Should Vorta continue to run in the background?</source>
        <translation>Soll Vorta im Hintergrund weiter ausgeführt werden?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="286"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="287"/>
        <source>Don&apos;t show this again</source>
        <translation>Zeige dies nicht erneut</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>Profile import successful!</source>
        <translation>Profil erfolgreich importiert!</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>Profile {} imported.</source>
        <translation>Profil {} importiert.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="220"/>
        <source>Load profile</source>
        <translation>Lade Profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="220"/>
        <source>JSON (*.json);;All files (*)</source>
        <translation>JSON (*.json);;Alle Dateien (*)</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="229"/>
        <source>Failed to import profile</source>
        <translation>Importieren des Profils fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="92"/>
        <source>Import from file…</source>
        <translation>Aus Datei importieren…</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="183"/>
        <source>Cannot delete the last profile.</source>
        <translation>Das letzte Profil kann nicht gelöscht werden.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="71"/>
        <source>Add a new profile (Dropdown: Import from file)</source>
        <translation>Ein neues Profil erstellen (Pull-down: Aus einer Datei importieren)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="87"/>
        <source>Rename current profile</source>
        <translation>Aktiviertes Profil umbenennen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="100"/>
        <source>Export current profile</source>
        <translation>Aktiviertes Profil exportieren</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="110"/>
        <source>Delete current profile</source>
        <translation>Aktiviertes Profil entfernen</translation>
    </message>
</context>
<context>
    <name>RepoTab</name>
    <message>
        <location filename="../../views/repo_tab.py" line="55"/>
        <source>No Compression</source>
        <translation>Keine Kompression</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="151"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>SSH-Schlüssel automatisch auswählen (Standardeinstellung)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="189"/>
        <source>Public Key Copied to Clipboard</source>
        <translation>Öffentlicher Schlüssel auf Zwischenablage kopiert</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="190"/>
        <source>The selected public SSH key was copied to the clipboard. Use it to set up remote repo permissions.</source>
        <translation>Der ausgewählte öffentliche SSH-Schlüssel wurde auf die Zwischenablage kopiert. Benutze dies, um die Zugriffsrechte des fernen Repositories einzurichten.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="197"/>
        <source>Select a public key from the dropdown first.</source>
        <translation>Wähle zuerst einen öffentlichen Schlüssel aus der Liste aus.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="264"/>
        <source>Repository was Unlinked</source>
        <translation>Repository-Verbindung wurde gelöst</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="265"/>
        <source>You can always connect it again later.</source>
        <translation>Sie können es jederzeit später wieder verbinden.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="45"/>
        <source>LZ4 (modern, default)</source>
        <translation>LZ4 (modern, standard)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="46"/>
        <source>Zstandard Level 3 (modern)</source>
        <translation>Zstandard Level 3 (modern)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="47"/>
        <source>Zstandard Level 8 (modern)</source>
        <translation>Zstandard Level 8 (modern)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="53"/>
        <source>ZLIB Level 6 (auto, legacy)</source>
        <translation>ZLIB Level 6 (automatisch, legacy)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="54"/>
        <source>LZMA Level 6 (auto, legacy)</source>
        <translation>LZMA Level 6 (automatisch, legacy)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="279"/>
        <source>Select a repository from the dropdown first.</source>
        <translation>Wähle zuerst ein Repository aus der Liste aus.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="33"/>
        <source>New Repository…</source>
        <translation>Neues Repository…</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="35"/>
        <source>Existing Repository…</source>
        <translation>Bestehendes Repository…</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="195"/>
        <source>Could not find public key.</source>
        <translation>Konnte öffentlichen Schlüssel nicht finden.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="104"/>
        <source>N/A</source>
        <comment>Not available.</comment>
        <translation>N/A</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="105"/>
        <source>Select a repository first.</source>
        <translation>Wähle zuerst ein Repository aus.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="106"/>
        <source>Try refreshing the metadata of any archive.</source>
        <translation>Versuche, die Metadaten eines Archivs zu aktualisieren.</translation>
    </message>
</context>
<context>
    <name>SSHAddWindow</name>
    <message>
        <location filename="../../views/ssh_dialog.py" line="52"/>
        <source>ED25519 (Recommended)</source>
        <translation>ED25519 (Empfohlen)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="53"/>
        <source>RSA (Legacy)</source>
        <translation>RSA (alt)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="54"/>
        <source>ECDSA</source>
        <translation>ECDSA</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="63"/>
        <source>High (Recommended)</source>
        <translation>Hoch (Empfohlen)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="64"/>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="77"/>
        <source>Key file already exists. Not overwriting.</source>
        <translation>Schlüssel-Datei existiert bereits, überschreibe nicht.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="89"/>
        <source>New key was copied to clipboard and written to %s.</source>
        <translation>Neuer Schlüssel wurde auf die Zwischenablage kopiert und geschrieben nach %s.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="91"/>
        <source>Error during key generation.</source>
        <translation>Fehler bei der Schlüssel-Erzeugung.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="48"/>
        <source>Generate and copy to clipboard</source>
        <translation>Erzeugen und in die Zwischenablage kopieren</translation>
    </message>
</context>
<context>
    <name>ScheduleTab</name>
    <message>
        <location filename="../../views/schedule_tab.py" line="46"/>
        <source>Minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="47"/>
        <source>Hours</source>
        <translation>Stunden</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="48"/>
        <source>Days</source>
        <translation>Tage</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="49"/>
        <source>Weeks</source>
        <translation>Wochen</translation>
    </message>
</context>
<context>
    <name>SourceTab</name>
    <message>
        <location filename="../../views/source_tab.py" line="290"/>
        <source>Choose directory to back up</source>
        <translation>Zu sicherndes Verzeichnis auswählen</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="290"/>
        <source>Choose file(s) to back up</source>
        <translation>Datei(en) für die Sicherung auswählen</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="281"/>
        <source>You don&apos;t have read access to {dir}.</source>
        <translation>Sie haben keinen Lesezugriff auf {dir}.</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="76"/>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="78"/>
        <source>Folders</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="80"/>
        <source>Paste</source>
        <translation>Aus der Zwischenablage einfügen</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="129"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="131"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="193"/>
        <source>Calculating…</source>
        <translation>Berechne...</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="360"/>
        <source>Some of your sources are invalid:</source>
        <translation>Folgende Datenquellen sind ungültig:</translation>
    </message>
</context>
<context>
    <name>TrayMenu</name>
    <message>
        <location filename="../../tray_menu.py" line="42"/>
        <source>Vorta for Borg Backup</source>
        <translation>Vorta for Borg Backup</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="53"/>
        <source>Cancel Backup</source>
        <translation>Datensicherung abbrechen</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="56"/>
        <source>Next Task: %s</source>
        <translation>Nächste Aufgabe: %s</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="65"/>
        <source>Backup Now</source>
        <translation>Datensicherung starten</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="70"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="52"/>
        <source>Task in progress</source>
        <translation>Vorgang läuft</translation>
    </message>
</context>
<context>
    <name>VortaApp</name>
    <message>
        <location filename="../../application.py" line="131"/>
        <source>Vorta Backup</source>
        <translation>Vorta Datensicherung</translation>
    </message>
    <message>
        <location filename="../../application.py" line="193"/>
        <source>No Borg Binary Found</source>
        <translation>Borg-Programm wurde nicht gefunden.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="194"/>
        <source>Vorta was unable to locate a usable Borg Backup binary.</source>
        <translation>Vorta konnte keine ausführbare Borg Backup Datei finden. </translation>
    </message>
    <message>
        <location filename="../../application.py" line="231"/>
        <source>Repository In Use</source>
        <translation>Repository wird verwendet</translation>
    </message>
    <message>
        <location filename="../../application.py" line="233"/>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../../application.py" line="234"/>
        <source>Continue</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../../application.py" line="236"/>
        <source>The repository at {repo_url} might be in use elsewhere.</source>
        <translation>Das Repository {repo_url} wird möglicherweise bereits verwendet.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="237"/>
        <source>Only break the lock if you are certain no other Borg process on any machine is accessing the repository. Abort or break the lock?</source>
        <translation>Hebe die Sperre nur auf, wenn du sichergestellt hast, dass keine weiteren Borg-Prozesse auf dem System auf das Repository zugreifen. Abbrechen oder Sperre aufheben?</translation>
    </message>
    <message>
        <location filename="../../application.py" line="245"/>
        <source>You do not have permission to access the repository at {repo_url}. Gain access and try again.</source>
        <translation>Du hast keine Berechtigung, um auf das Repository auf {repo_url} zuzugreifen. Erhalte Zugang und versuche es erneut.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="248"/>
        <source>No Repository Permissions</source>
        <translation>Keine Berechtigung für Repository</translation>
    </message>
    <message>
        <location filename="../../application.py" line="212"/>
        <source>Vorta needs Full Disk Access for complete Backups</source>
        <translation>Für komplette Sicherungen benötigt Vorta Vollzugriff auf die Festplatte</translation>
    </message>
    <message>
        <location filename="../../application.py" line="285"/>
        <source>Profile import successful!</source>
        <translation>Profil erfolgreich importiert!</translation>
    </message>
    <message>
        <location filename="../../application.py" line="285"/>
        <source>Profile {} imported.</source>
        <translation>Profil {} importiert.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="272"/>
        <source>Failed to import profile</source>
        <translation>Importieren des Profils fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../../application.py" line="272"/>
        <source>Failed to import a profile from {}:</source>
        <translation>Importieren eines Profils fehlgeschlagen von {}:</translation>
    </message>
    <message>
        <location filename="../../application.py" line="272"/>
        <source>Consider removing or repairing this file to get rid of this message.</source>
        <translation>Diese Datei sollte entfernt oder repariert werden, um diese Nachricht loszuwerden.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="324"/>
        <source>Repo Check Failed</source>
        <translation>Überprüfung des Repositorys fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../../application.py" line="213"/>
        <source>Without this, some files will not be accessible and you may end up with an incomplete backup. Please set &lt;b&gt;Full Disk Access&lt;/b&gt; permission for Vorta in &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;System Preferences &gt; Security &amp; Privacy&lt;/a&gt;.</source>
        <translation>Auf einige Dateien kann ohne diese Berechtigung nicht zugegriffen werden. Dies kann zu unvollständigen Sicherungen führen. Gewähren Sie Vorta bitte den &lt;b&gt;Vollzugriff auf die Festplatte&lt;/b&gt; unter &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;Systemeinstellungen &gt; Sicherheit &amp; Privatsphäre&lt;/a&gt;. </translation>
    </message>
    <message>
        <location filename="../../application.py" line="329"/>
        <source>Borg exited with a warning message. See logs for details.</source>
        <translation>Datensicherung mit Warnmeldungen beendet. Details finden sich in den Logs.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="334"/>
        <source>Repository data check for repo was killed by signal %s.</source>
        <translation>Überprüfung des Repositorys wurde durch Signal %s abgebrochen.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="338"/>
        <source>The process running the check job got a kill signal. Try again.</source>
        <translation>Der Prozess, der die Überprüfung ausführt empfing a &quot;kill&quot;-Signal. Versuchen Sie es erneut.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="341"/>
        <source>Repository data check for repo %s failed. Error code %s</source>
        <translation>Überprüfung des Repositorys %s fehlgeschlagen. Fehlercode %s</translation>
    </message>
    <message>
        <location filename="../../application.py" line="346"/>
        <source>Consider repairing or recreating the repository soon to avoid missing data.</source>
        <translation>Möglicherweise sollte das Repository zeitnah repariert oder neu erstellt werden, um einen Datenverlust zu verhindern.</translation>
    </message>
</context>
<context>
    <name>VortaScheduler</name>
    <message>
        <location filename="../../scheduler.py" line="199"/>
        <source>None scheduled</source>
        <translation>Keine geplant.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="246"/>
        <source>Vorta Backup</source>
        <translation>Vorta Datensicherung</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="218"/>
        <source>Starting background backup for %s.</source>
        <translation>Starte Datensicherung (Hintergrund) für %s.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="240"/>
        <source>Backup successful for %s.</source>
        <translation>Datensicherung erfolgreich abgeschlossen für %s.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="246"/>
        <source>Error during backup creation.</source>
        <translation>Fehler während der Datensicherung aufgetreten.</translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="../../__main__.py" line="22"/>
        <source>Fatal Error</source>
        <translation>Schwerwiegender Fehler</translation>
    </message>
    <message>
        <location filename="../../__main__.py" line="23"/>
        <source>Uncaught exception, please file a report with this text at
https://github.com/borgbase/vorta/issues/new
</source>
        <translation>Unbehandelter Fehler, bitte melde dies mit diesem Text auf
https://github.com/borgbase/vorta/issues/new
</translation>
    </message>
</context>
<context>
    <name>messages</name>
    <message>
        <location filename="../../borg/version.py" line="20"/>
        <source>Borg binary was not found.</source>
        <translation>Borg-Programm wurde nicht gefunden.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="140"/>
        <source>Add a backup repository first.</source>
        <translation>Zuerst ein Datensicherungs-Repository hinzufügen.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="82"/>
        <source>Add some folders to back up first.</source>
        <translation>Füge zuerst einige zu sichernde Ordner hinzu.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="98"/>
        <source>Current Wifi is not allowed.</source>
        <translation>Aktuelles WLAN ist nicht erlaubt.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="115"/>
        <source>Repo folder not mounted or moved.</source>
        <translation>Repo-Ordner nicht eingehängt oder verschoben.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="111"/>
        <source>Pre-backup command returned non-zero exit code.</source>
        <translation>Pre-backup-Kommando hat einen Return-Code ungleich Null zurückgegeben.</translation>
    </message>
    <message>
        <location filename="../../borg/umount.py" line="27"/>
        <source>No active Borg mounts found.</source>
        <translation>Keine aktiven Borg-Einhängepunkte gefunden.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="144"/>
        <source>Your Borg version is too old. &gt;=1.1.0 is required.</source>
        <translation>Ihre Borg Version ist zu alt. &gt;=1.1.0 ist notwendig.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="119"/>
        <source>Your current Borg version does not support ZStd compression.</source>
        <translation>Ihre Borg version unterstützt ZStd Kompression nicht.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="103"/>
        <source>Not running backup over metered connection.</source>
        <translation>Sicherung über kostenpflichtige Verbindung wird nicht durchgeführt.</translation>
    </message>
    <message>
        <location filename="../../borg/info_repo.py" line="43"/>
        <source>Please unlock your password manager.</source>
        <translation>Bitte Passwortmanager entsperren.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="171"/>
        <source>Your repo passphrase was stored in a password manager which is no longer available.
Try unlinking and re-adding your repo.</source>
        <translation>Das Passwort für das Repository ist in einem nicht mehr unterstützten Passwortmanager gespeichert. Versuche, das Repository abzukoppeln und neu hinzuzufügen.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="155"/>
        <source>Please unlock your system password manager or disable it under Misc</source>
        <translation>Bitte Passwortmanager entsperren oder unter Diverses deaktivieren.</translation>
    </message>
    <message>
        <location filename="../../borg/compact.py" line="39"/>
        <source>This feature needs Borg 1.2.0 or higher.</source>
        <translation>Diese Funktionalität benötigt mindestens Version 1.2.0 von Borg.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="165"/>
        <source>Starting backup…</source>
        <translation>Starte Datensicherung…</translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <location filename="../../store/settings.py" line="27"/>
        <source>Display notifications when background tasks fail</source>
        <translation>Benachrichtigungen anzeigen, falls Hintergrund-Aufgaben fehlschlagen</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="33"/>
        <source>Also notify about successful background tasks</source>
        <translation>Auch über erfolgreiche Hintergrund-Aufgaben benachrichtigen</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="39"/>
        <source>Automatically start Vorta at login</source>
        <translation>Vorta automatisch bei der Anmeldung starten</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="45"/>
        <source>Open main window on startup</source>
        <translation>Hauptfenster beim Starten öffnen</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="51"/>
        <source>Get statistics of file/folder when added</source>
        <translation>Größe berechnen, wenn neue Dateien oder Ordner hinzugefügt werden</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="83"/>
        <source>Check for updates on startup</source>
        <translation>Prüfe beim Start auf Aktualisierungen</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="88"/>
        <source>Include pre-release versions when checking for updates</source>
        <translation>Auch Vorab-Versionen bei der Prüfung auf Aktualisierungen miteinbeziehen</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="17"/>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="18"/>
        <source>Startup</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="19"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="20"/>
        <source>Security</source>
        <translation>Sicherheit</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="57"/>
        <source>Store repository passwords in system keychain, if available</source>
        <translation>Repository-Passwörter falls verfügbar im Schlüsselbund des Betriebssystems speichern</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="63"/>
        <source>Try to replace existing permissions when mounting an archive</source>
        <translation>Beim Einhängen eines Archivs versuchen bestehende Berechtigungen zu ersetzen</translation>
    </message>
    <message>
        <location filename="../../store/settings.py" line="98"/>
        <source>If the system tray isn&apos;t available, ask whether to continue in the background on exit</source>
        <translation>Falls die Taskleiste nicht verfügbar ist: Frage nach, ob beim Schliessen die Applikation im Hintergrund weiterlaufen soll.</translation>
    </message>
</context>
<context>
    <name>utils</name>
    <message>
        <location filename="../../utils.py" line="403"/>
        <source>Passwords must be identical and greater than 8 characters long.</source>
        <translation>Passwörter müssen übereinstimmen und mindestens 8 Zeichen lang sein.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="405"/>
        <source>Passwords must be identical.</source>
        <translation>Passwörter müssen übereinstimmen.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="407"/>
        <source>Passwords must be greater than 8 characters long.</source>
        <translation>Passwörter müssen länger als 8 Zeichen sein.</translation>
    </message>
</context>
</TS>